@@ -3,7 +3,7 @@ __author__ = 'ninja'
 """ This is a sample piece of code written as part
     of the head first python text """
 
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
     """ this is the function that takes each member of a list
         and checks if the member is a list itself. It recursively prints
         out all the individual members of the nested lists """
